<template>
  <a-drawer
    :title="title"
    :width="drawerWidth"
    :visible="visible"
    @close="handleCancel"
    :confirmLoading="confirmLoading"
    :maskClosable="maskClosable"
  >
    <a-card :style="getBackground()">
      <template>
        <a-card>
          <div :style="{width: '100%',border: '1px solid #e9e9e9',padding: '10px 16px',background: '#fff',}">
            <a-row :gutter="24">
              <a-col :span="6">
                <a-form-item
                  :labelCol="labelCol"
                  :wrapperCol="wrapperCol"
                  label="统一编码"
                  class="hightColor"
                >
                  <span
                    v-if="this.model != null"
                    class="hightColor"
                  >{{ this.model.num }}</span>
                  <span
                    v-else
                    class="frozenRowClass"
                  >-</span>
                </a-form-item>
              </a-col>
              <a-col :span="6">
                <a-form-item
                  :labelCol="labelCol"
                  :wrapperCol="wrapperCol"
                  label="设备名称"
                  class="hightColor"
                >
                  <span
                    v-if="this.model != null"
                    class="hightColor"
                  >{{ this.model.name }}</span>
                  <span
                    v-else
                    class="frozenRowClass"
                  >-</span>
                </a-form-item>
              </a-col>
              <a-col :span="6">
                <a-form-item
                  :labelCol="labelCol"
                  :wrapperCol="wrapperCol"
                  label="规格"
                  class="hightColor"
                >
                  <span
                    v-if="this.model != null"
                    class="hightColor"
                  >{{ this.model.specification }}</span>
                  <span
                    v-else
                    class="frozenRowClass"
                  >-</span>
                </a-form-item>
              </a-col>
              <a-col :span="6">
                <a-form-item
                  :labelCol="labelCol"
                  :wrapperCol="wrapperCol"
                  label="型号"
                  class="hightColor"
                >
                  <span
                    v-if="this.model != null"
                    class="hightColor"
                  >{{ this.model.model }}</span>
                  <span
                    v-else
                    class="frozenRowClass"
                  >-</span>
                </a-form-item>
              </a-col>
            </a-row>
          </div>

          <a-tabs
            type="card"
            defaultActiveKey="1"
          >
            <a-tab-pane
              tab='使用记录'
              key="1"
              class="hightColor"
            >
              <div>
                <a-table
                  ref="table"
                  size="middle"
                  bordered
                  rowKey="id"
                  :columns="columns"
                  :dataSource="dataSource"
                  :loading="loading"
                  @change="handleTableChange"
                  :pagination="ipagination"
                >
                  <!-- :scroll="{ x: 'calc(1000px + 50%)', y: 900 }" -->
                </a-table>
              </div>
            </a-tab-pane>

            <a-tab-pane
              tab='点检记录'
              key="2"
            >
              <div
                class="table-operator"
                style="margin:-16px"
              >
                <equipment-inspection-record :equipmentId='equipmentId' />
              </div>
            </a-tab-pane>
            <a-tab-pane
              tab='保养记录'
              key="3"
            >
              <div
                class="table-operator"
                style="margin:-16px"
              >
                <equipment-maintenance-record :equipmentId='equipmentId' />
              </div>
            </a-tab-pane>
            <a-tab-pane
              tab='维修记录'
              key="4"
            >
              <div
                class="table-operator"
                style="margin:-16px"
              >
                <equipment-repair-record :equipmentId='equipmentId' />
              </div>
            </a-tab-pane>
            <a-tab-pane
              tab='换件记录'
              key="5"
            >
              <div
                class="table-operator"
                style="margin:-16px"
              >
                <equipment-spare-record :equipmentId="equipmentId" />
              </div>
            </a-tab-pane>
            <a-tab-pane
              tab='鉴定记录'
              key="6"
            >
              <div
                class="table-operator"
                style="margin:-16px"
              >
                <equipment-calibration-record :equipmentId="equipmentId" />
              </div>
            </a-tab-pane>
            <a-tab-pane
              tab='处理记录'
              key="7"
            >
              <div
                class="table-operator"
                style="margin:-16px"
              >
                <equipment-change-record :equipmentId="equipmentId" />
              </div>
            </a-tab-pane>
          </a-tabs>
        </a-card>
        <div :style="{width: '100%',border: '1px solid #e9e9e9',padding: '10px 16px',background: '#fff',}">
          <a-row :style="{textAlign:'right'}">
            <a-button
              :style="{marginRight: '8px'}"
              @click="handleCancel"
            >
              取消
            </a-button>
          </a-row>
        </div>
      </template>
    </a-card>
  </a-drawer>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { requestPut, getAction, downFile } from '@/api/manage'
import Tooltip from 'ant-design-vue/es/tooltip'
import { ACCESS_TOKEN } from '@/store/mutation-types'
import Vue from 'vue'
import { getFileAccessHttpUrl } from '@/api/manage';

import EquipmentInspectionRecord from './EquipmentInspectionRecord'
import EquipmentMaintenanceRecord from './EquipmentMaintenanceRecord'
import EquipmentRepairRecord from './EquipmentRepairRecord'
import EquipmentSpareRecord from './EquipmentSpareRecord.vue'
import EquipmentCalibrationRecord from './EquipmentCalibrationRecord.vue'
import EquipmentChangeRecord from './EquipmentChangeRecord.vue'

export default {
  name: 'EquipmentResumeDrawer',
  mixins: [JeecgListMixin],
  components: {
    Tooltip,
    EquipmentInspectionRecord,
    EquipmentMaintenanceRecord,
    EquipmentRepairRecord,
    EquipmentCalibrationRecord,
    EquipmentSpareRecord,
    EquipmentChangeRecord,

  },
  data() {
    return {
      title: "设备履历",
      visible: false,
      maskClosable: true,
      confirmLoading: false,
      drawerWidth: "100%",
      equipmentId: '-1',
      dataSource: [],
      model: {},
      ipagination: {
        current: 1,
        pageSize: 5,
        pageSizeOptions: ['5', '10', '20'],
        showTotal: (total, range) => {
          return range[0] + "-" + range[1] + " 共" + total + "条"
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      labelCol: {
        xs: { span: 24 },
        sm: { span: 6 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 18 },
      },
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          width: 50,
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '单据号',
          align: 'center',
          dataIndex: 'num',
        },
        {
          title: '单据类型',
          align: 'center',
          dataIndex: 'type',
        },
        {
          title: '业务类型',
          align: 'center',
          dataIndex: 'businessType',
        },
        {
          title: '经办人',
          align: 'center',
          dataIndex: 'createBy',
        },
        {
          title: '业务日期',
          align: 'center',
          dataIndex: 'createTime',
        },
      ],
      url: {
        list: "/eam/equipment/getResumeUseRecordList",
      },
    }
  },
  mounted() {
    this.$bus.$on('closeDrawer', (data) => {
      this.visible = false;
    })
  },

  methods: {

    handleShow(record) {
      this.model = Object.assign({}, record);
      this.equipmentId = record.id
      this.dataSource = []
      this.visible = true;
      this.queryParam.equipmentId = record.id
      this.loadData(1)
    },

    loadData(arg) {
      if (!this.url.list) {
        this.$message.error("请设置url.list属性!")
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1;
      }
      var params = this.getQueryParams();//查询条件
      this.loading = true;
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          //update-begin---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
          this.dataSource = res.result.records || res.result;
          if (res.result.total) {
            this.ipagination.total = res.result.total;
          } else {
            this.ipagination.total = 0;
          }
          //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
        } else {
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    },

    // loadData() {
    // },
    getBackground() {
      return "background-color:rgba(127, 127, 127,0.08)";
    },
    handleCancel() {
      this.$emit('ok');
      this.alterFlag = new Date();
      this.close()
    },
    close() {
      this.visible = false;
    },

  },
}
</script>

<style scoped>
@import '~@assets/less/common.less';
.hightColor {
  height: 10%;
  font-weight: bold;
  font-size: 20px;
  color: #1b1e1e;
}
.frozenRowClass {
  color: #c9c9c9;
}
.fontweight {
  font-weight: bold;
}
.hight {
  color: #f5222d;
}
/deep/ .red {
  color: red;
}
</style>